.. Copyright (C) 2017 nickolas360 <contact@nickolas360.com>

.. This file is part of pyrcb2-docs, documentation for pyrcb2.

.. pyrcb2-docs is licensed under the GNU Lesser General Public License
   as published by the Free Software Foundation, either version 3 of
   the License, or (at your option) any later version.

.. As an additional permission under GNU GPL version 3 section 7, you
   may distribute non-source forms of pyrcb2-docs without the copy of
   the GNU GPL normally required by section 4, provided you include a
   URL through which recipients can obtain a copy of the Corresponding
   Source and the GPL at no charge.

.. pyrcb2-docs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

.. You should have received a copy of the GNU Lesser General Public License
   along with pyrcb2-docs.  If not, see <http://www.gnu.org/licenses/>.

.. currentmodule:: pyrcb2

Version 0.3
===========

Changelog
---------

.. _changelog-0.3.3:

0.3.3
~~~~~

* Fixed a minor error in the documentation.

.. _changelog-0.3.2:

0.3.2
~~~~~

* Fixed an issue with account tracking when users change nicknames. A user's
  account should stay synced when they change nicknames, but previously, their
  account would not be synced if they switched to their previous nickname
  (e.g., user1 → user2 → user1).

.. _changelog-0.3.1:

0.3.1
~~~~~

* Fixed a bug where :meth:`IRCBot.split_string` would sometimes remove too many
  spaces.
* Corrected the behavior of :meth:`IRCBot.split_string` to split based on
  graphemes, not code points. Graphemes will no longer be split unless
  absolutely necessary (specifically, if they are longer than the maximum byte
  length allowed).
* :meth:`IRCBot.connect` now raises a `ValueError` when a client certificate
  is specified but ``ssl`` is false.

.. _changelog-0.3.0:

0.3.0
~~~~~

* Added support for the SASL "EXTERNAL" mechanism.
* :meth:`IRCBot.connect` now accepts client certificates.
* The ``ssl`` parameter in :meth:`IRCBot.connect` can now be an
  `ssl.SSLContext` object to be used instead of the default context.
